@@ -91,7 +91,7 @@ def good_object_id(env):
 
 @pytest.fixture(scope="session")
 def object_id_delimiter(env):
-    return env[_object_id + "_DELIMITER"]
+    return env["object_id_delimiter"]
 
 
 @pytest.fixture(scope="session")
